==> nextcloud-app-tasks-0.9.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/et_EE.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Ülesanded",
    "Due yesterday" : "Tähtaeg oli eile",
    "Due today" : "Tähtaeg on täna",
    "Due tomorrow" : "Tähtaeg on homme",
    "Due on" : "Tähtaeg",
    "Started yesterday" : "Algas eile",
    "Starts today" : "Algab täna",
    "Starts tomorrow" : "Algab homme",
    "Started on" : "Algas",
    "Starts on" : "Algab",
    "[Remind me yesterday at ]HH:mm" : "[Tuleta mulle meelde eile kell ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Tuleta mulle meelde täna kell ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Tuleta mulle meelde homme kell ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Tuleta mulle meelde ]MMM DD, YYYY,[ kell ]HH:mm",
    "Yesterday" : "Eile",
    "Today" : "Täna",
    "Tomorrow" : "Homme",
    "in %s" : "kaustas %s",
    "%s ago" : "%s tagasi",
    "seconds" : "sekundit",
    "a minute" : "minut",
    "%d minutes" : "%d minutit",
    "an hour" : "tund",
    "%d hours" : "%d tundi",
    "a day" : "päev",
    "%d days" : "%d päeva",
    "a month" : "kuu",
    "%d months" : "%d kuud",
    "a year" : "aasta",
    "%d years" : "%d aastat",
    "week" : "nädal",
    "weeks" : "nädalat",
    "day" : "päev",
    "days" : "päeva",
    "hour" : "tund",
    "hours" : "tundi",
    "minute" : "minut",
    "minutes" : "minutit",
    "second" : "teine",
    "before beginning" : "enne algust",
    "after beginning" : "pärast algust",
    "before end" : "enne lõppu",
    "after end" : "pärast lõppu",
    "Comment" : "Kommentaar",
    "Add a comment" : "Lisa kommentaar",
    "This will delete the Calendar \"%s\" and all of its entries." : "See kustutab kalendri \"%s\" ja kõik selle sissekanded.",
    "The name \"%s\" is already used." : "Nimi \"%s\" on juba kasutuses.",
    "An empty name is not allowed." : "Nime lahter ei tohi olla tühi.",
    "Hidden" : "Peidetud",
    "Visible" : "Nähtav",
    "Automatic" : "Automaatne",
    "Sunday" : "Pühapäev",
    "Monday" : "Esmaspäev",
    "Tuesday" : "Teisipäev",
    "Wednesday" : "Kolmapäev",
    "Thursday" : "Neljapäev",
    "Friday" : "Reede",
    "Saturday" : "Laupäev",
    "Add an important item in \"%s\"..." : "Lisa oluline kirje nimekirja \"%s\"...",
    "Add an item due today in \"%s\"..." : "Lisa tänase tähtajaga kirje nimekirja \"%s\"...",
    "Add an item in \"%s\"..." : "Lisa kirje nimekirja \"%s\"...",
    "Add a current item in \"%s\"..." : "Lisa praegune kirje nimekirja \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n lõpetatud ülesanne","%n lõpetatud ülesannet"],
    "Hours" : "Tundi",
    "Minutes" : "Minutit",
    "Set due date" : "Määra tähtaeg",
    "%s %% completed" : "%s %% valmis",
    "priority %s: " : "tähtsus %s: ",
    "high" : "kõrge",
    "medium" : "keskmine",
    "low" : "madal",
    "no priority assigned" : "tähtsust pole määratud",
    "Remind me" : "Tuleta meelde",
    "at the end" : "lõpus",
    "at the beginning" : "alguses",
    "Set start date" : "Määra alguse kuupäev",
    "{calendar} shared by {owner}" : "{calendar} jagas {owner}",
    "Unnamed" : "Nimeta",
    "Important" : "Tähtis",
    "Week" : "Nädal",
    "All" : "Kõik",
    "Current" : "Praegune",
    "Completed" : "Lõpetatud",
    "Delete" : "Kustuta",
    "Cancel" : "Loobu",
    "Edit" : "Muuda",
    "Link" : "Link",
    "Download" : "Lae alla",
    "Save" : "Salvesta",
    "Add List..." : "Lisa nimekirja...",
    "New List" : "Uus nimekiri",
    "Settings" : "Seaded",
    "Start of week" : "Nädala algus",
    "Visibility of Smart Collections" : "Nutikate kollektsioonide nähtavus",
    "Default" : "Vaikeväärtus",
    "Load remaining completed tasks." : "Laadi ülejäänud lõpetatud ülesanded",
    "(New category)" : "(Uus kategooria)",
    "Select categories..." : "Vali kategooriad...",
    "Loading the task..." : "Ülesande laadimine...",
    "Task not found!" : "Ülesannet ei leitud!"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.9.6-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/et_EE.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Ülesanded",
    "Due yesterday" : "Tähtaeg oli eile",
    "Due today" : "Tähtaeg on täna",
    "Due tomorrow" : "Tähtaeg on homme",
    "Due on" : "Tähtaeg",
    "Started yesterday" : "Algas eile",
    "Starts today" : "Algab täna",
    "Starts tomorrow" : "Algab homme",
    "Started on" : "Algas",
    "Starts on" : "Algab",
    "[Remind me yesterday at ]HH:mm" : "[Tuleta mulle meelde eile kell ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Tuleta mulle meelde täna kell ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Tuleta mulle meelde homme kell ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Tuleta mulle meelde ]MMM DD, YYYY,[ kell ]HH:mm",
    "Yesterday" : "Eile",
    "Today" : "Täna",
    "Tomorrow" : "Homme",
    "in %s" : "kaustas %s",
    "%s ago" : "%s tagasi",
    "seconds" : "sekundit",
    "a minute" : "minut",
    "%d minutes" : "%d minutit",
    "an hour" : "tund",
    "%d hours" : "%d tundi",
    "a day" : "päev",
    "%d days" : "%d päeva",
    "a month" : "kuu",
    "%d months" : "%d kuud",
    "a year" : "aasta",
    "%d years" : "%d aastat",
    "week" : "nädal",
    "weeks" : "nädalat",
    "day" : "päev",
    "days" : "päeva",
    "hour" : "tund",
    "hours" : "tundi",
    "minute" : "minut",
    "minutes" : "minutit",
    "second" : "teine",
    "before beginning" : "enne algust",
    "after beginning" : "pärast algust",
    "before end" : "enne lõppu",
    "after end" : "pärast lõppu",
    "Comment" : "Kommentaar",
    "Add a comment" : "Lisa kommentaar",
    "This will delete the Calendar \"%s\" and all of its entries." : "See kustutab kalendri \"%s\" ja kõik selle sissekanded.",
    "The name \"%s\" is already used." : "Nimi \"%s\" on juba kasutuses.",
    "An empty name is not allowed." : "Nime lahter ei tohi olla tühi.",
    "Hidden" : "Peidetud",
    "Visible" : "Nähtav",
    "Automatic" : "Automaatne",
    "Sunday" : "Pühapäev",
    "Monday" : "Esmaspäev",
    "Tuesday" : "Teisipäev",
    "Wednesday" : "Kolmapäev",
    "Thursday" : "Neljapäev",
    "Friday" : "Reede",
    "Saturday" : "Laupäev",
    "Add an important item in \"%s\"..." : "Lisa oluline kirje nimekirja \"%s\"...",
    "Add an item due today in \"%s\"..." : "Lisa tänase tähtajaga kirje nimekirja \"%s\"...",
    "Add an item in \"%s\"..." : "Lisa kirje nimekirja \"%s\"...",
    "Add a current item in \"%s\"..." : "Lisa praegune kirje nimekirja \"%s\"...",
    "Add a subtask to \"%s\"..." : "\"%s\" alamülesande lisamine...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n lõpetatud ülesanne","%n lõpetatud ülesannet"],
    "Hours" : "Tundi",
    "Minutes" : "Minutit",
    "Set due date" : "Määra tähtaeg",
    "%s %% completed" : "%s %% valmis",
    "priority %s: " : "tähtsus %s: ",
    "high" : "kõrge",
    "medium" : "keskmine",
    "low" : "madal",
    "no priority assigned" : "tähtsust pole määratud",
    "Remind me" : "Tuleta meelde",
    "at the end" : "lõpus",
    "at the beginning" : "alguses",
    "Set start date" : "Määra alguse kuupäev",
    "{calendar} shared by {owner}" : "{calendar} jagas {owner}",
    "Unnamed" : "Nimeta",
    "Important" : "Tähtis",
    "Week" : "Nädal",
    "All" : "Kõik",
    "Current" : "Praegune",
    "Completed" : "Lõpetatud",
    "Delete" : "Kustuta",
    "Cancel" : "Loobu",
    "Edit" : "Muuda",
    "Link" : "Link",
    "Download" : "Lae alla",
    "Save" : "Salvesta",
    "Add List..." : "Lisa nimekiri...",
    "New List" : "Uus nimekiri",
    "Settings" : "Seaded",
    "Start of week" : "Nädala algus",
    "Visibility of Smart Collections" : "Nutikate kollektsioonide nähtavus",
    "Change sort order" : "Muuda sorteerimisjärjekorda",
    "Default" : "Vaikeväärtus",
    "Due date" : "Tähtaeg",
    "Start date" : "Alguskuupäev",
    "Priority" : "Prioriteet",
    "Alphabetically" : "Tähestikujärjekorras",
    "Manually" : "Käsitsi",
    "Load remaining completed tasks." : "Laadi ülejäänud lõpetatud ülesanded",
    "Task is completed" : "Ülesanne on tehtud",
    "All day" : "Kogu päev",
    "(New category)" : "(Uus kategooria)",
    "Select categories..." : "Vali kategooriad...",
    "Loading the task..." : "Ülesande laadimine...",
    "Task not found!" : "Ülesannet ei leitud!",
    "add a subtask to" : "lisa alamülesanne",
    "Toggle subtasks" : "Näita alamülesandeid",
    "Toggle completed subtasks" : "Näita lõpetatud alamülesandeid"
},
"nplurals=2; plural=(n != 1);");
